Class: Google::Apis::DeploymentmanagerV2beta::FirewallPolicyRuleOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::FirewallPolicyRuleOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Instance Attribute Summary collapse
-
#allocated_priority ⇒ Fixnum
The priority allocated for the firewall policy rule if query parameters specified minPriority/maxPriority.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyRuleOperationMetadata
constructor
A new instance of FirewallPolicyRuleOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyRuleOperationMetadata
Returns a new instance of FirewallPolicyRuleOperationMetadata.
994 995 996 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 994 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocated_priority ⇒ Fixnum
The priority allocated for the firewall policy rule if query parameters
specified minPriority/maxPriority.
Corresponds to the JSON property allocatedPriority
992 993 994 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 992 def allocated_priority @allocated_priority end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
999 1000 1001 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 999 def update!(**args) @allocated_priority = args[:allocated_priority] if args.key?(:allocated_priority) end |