Class: Google::Apis::DeploymentmanagerV2beta::GetVersionOperationMetadataSbomInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetVersionOperationMetadataSbomInfo

Returns a new instance of GetVersionOperationMetadataSbomInfo.



1039
1040
1041
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1039

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_component_versionsHash<String,String>

SBOM versions currently applied to the resource. The key is the component name and the value is the version. Corresponds to the JSON property currentComponentVersions

Returns:

  • (Hash<String,String>)


1031
1032
1033
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1031

def current_component_versions
  @current_component_versions
end

#target_component_versionsHash<String,String>

SBOM versions scheduled for the next maintenance. The key is the component name and the value is the version. Corresponds to the JSON property targetComponentVersions

Returns:

  • (Hash<String,String>)


1037
1038
1039
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1037

def target_component_versions
  @target_component_versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1044
1045
1046
1047
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1044

def update!(**args)
  @current_component_versions = args[:current_component_versions] if args.key?(:current_component_versions)
  @target_component_versions = args[:target_component_versions] if args.key?(:target_component_versions)
end