Class: Google::Apis::DeploymentmanagerV2beta::Help

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb

Overview

Provides links to documentation or for performing an out of band action. For example, if a quota check failed with an error indicating the calling project hasn't enabled the accessed service, this can contain a URL pointing directly to the right place in the developer console to flip the bit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Help

Returns a new instance of Help.



1128
1129
1130
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

URL(s) pointing to additional information on handling the current error. Corresponds to the JSON property links



1126
1127
1128
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1126

def links
  @links
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1133
1134
1135
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1133

def update!(**args)
  @links = args[:links] if args.key?(:links)
end