Class: Google::Apis::DeploymentmanagerV2beta::LocalizedMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb

Overview

Provides a localized error message that is safe to return to the user which can be attached to an RPC error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocalizedMessage

Returns a new instance of LocalizedMessage.



1223
1224
1225
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#localeString

The locale used following the specification defined at https://www.rfc-editor. org/rfc/bcp/bcp47.txt. Examples are: "en-US", "fr-CH", "es-MX" Corresponds to the JSON property locale

Returns:

  • (String)


1216
1217
1218
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1216

def locale
  @locale
end

#messageString

The localized error message in the above locale. Corresponds to the JSON property message

Returns:

  • (String)


1221
1222
1223
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1221

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1228
1229
1230
1231
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1228

def update!(**args)
  @locale = args[:locale] if args.key?(:locale)
  @message = args[:message] if args.key?(:message)
end