Class: Google::Apis::DeploymentmanagerV2beta::Operation
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::Operation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Overview
Represents an Operation resource. Google Compute Engine has three Operation
resources: * Global * Regional * Zonal You can use an operation resource to manage asynchronous API
requests. For more information, read Handling API responses. Operations can be
global, regional or zonal. - For global operations, use the globalOperations
resource. - For regional operations, use the regionOperations resource. -
For zonal operations, use the zoneOperations resource. For more information,
read Global, Regional, and Zonal Resources. Note that completed Operation
resources have a limited retention period.
Defined Under Namespace
Instance Attribute Summary collapse
-
#client_operation_id ⇒ String
[Output Only] The value of
requestIdif you provided it in the request. -
#creation_timestamp ⇒ String
[Deprecated] This field is deprecated.
-
#description ⇒ String
[Output Only] A textual description of the operation, which is set when the operation is created.
-
#end_time ⇒ String
[Output Only] The time that this operation was completed.
-
#error ⇒ Google::Apis::DeploymentmanagerV2beta::Operation::Error
[Output Only] If errors are generated during processing of the operation, this field will be populated.
-
#firewall_policy_rule_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::FirewallPolicyRuleOperationMetadata
Corresponds to the JSON property
firewallPolicyRuleOperationMetadata. -
#get_version_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::GetVersionOperationMetadata
Corresponds to the JSON property
getVersionOperationMetadata. -
#http_error_message ⇒ String
[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as
NOT FOUND. -
#http_error_status_code ⇒ Fixnum
[Output Only] If the operation fails, this field contains the HTTP error status code that was returned.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the operation.
-
#insert_time ⇒ String
[Output Only] The time that this operation was requested.
-
#instances_bulk_insert_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::InstancesBulkInsertOperationMetadata
Corresponds to the JSON property
instancesBulkInsertOperationMetadata. -
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the operation.
-
#operation_group_id ⇒ String
Output only.
-
#operation_type ⇒ String
[Output Only] The type of operation, such as
insert,update, ordelete, and so on. -
#progress ⇒ Fixnum
[Output Only] An optional progress indicator that ranges from 0 to 100.
-
#region ⇒ String
[Output Only] The URL of the region where the operation resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#set_autoscaler_link_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::SetAutoscalerLinkOperationMetadata
This field is used internally by the Autoscaler team and should not be promoted to "alpha/beta/v1".
-
#set_common_instance_metadata_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::SetCommonInstanceMetadataOperationMetadata
Output only.
-
#start_time ⇒ String
[Output Only] The time that this operation was started by the server.
-
#status ⇒ String
[Output Only] The status of the operation, which can be one of the following:
PENDING,RUNNING, orDONE. -
#status_message ⇒ String
[Output Only] An optional textual description of the current status of the operation.
-
#target_id ⇒ Fixnum
[Output Only] The unique target ID, which identifies a specific incarnation of the target resource.
-
#target_link ⇒ String
[Output Only] The URL of the resource that the operation modifies.
-
#user ⇒ String
[Output Only] User who requested the operation, for example:
user@example.comoralice_smith_identifier (global/workforcePools/example-com-us-employees). -
#warnings ⇒ Array<Google::Apis::DeploymentmanagerV2beta::Operation::Warning>
[Output Only] If warning messages are generated during processing of the operation, this field will be populated.
-
#zone ⇒ String
[Output Only] The URL of the zone where the operation resides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Operation
constructor
A new instance of Operation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Operation
Returns a new instance of Operation.
1573 1574 1575 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1573 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_operation_id ⇒ String
[Output Only] The value of requestId if you provided it in the request. Not
present otherwise.
Corresponds to the JSON property clientOperationId
1398 1399 1400 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1398 def client_operation_id @client_operation_id end |
#creation_timestamp ⇒ String
[Deprecated] This field is deprecated.
Corresponds to the JSON property creationTimestamp
1403 1404 1405 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1403 def @creation_timestamp end |
#description ⇒ String
[Output Only] A textual description of the operation, which is set when the
operation is created.
Corresponds to the JSON property description
1409 1410 1411 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1409 def description @description end |
#end_time ⇒ String
[Output Only] The time that this operation was completed. This value is in
RFC3339 text format.
Corresponds to the JSON property endTime
1415 1416 1417 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1415 def end_time @end_time end |
#error ⇒ Google::Apis::DeploymentmanagerV2beta::Operation::Error
[Output Only] If errors are generated during processing of the operation, this
field will be populated.
Corresponds to the JSON property error
1421 1422 1423 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1421 def error @error end |
#firewall_policy_rule_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::FirewallPolicyRuleOperationMetadata
Corresponds to the JSON property firewallPolicyRuleOperationMetadata
1426 1427 1428 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1426 def @firewall_policy_rule_operation_metadata end |
#get_version_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::GetVersionOperationMetadata
Corresponds to the JSON property getVersionOperationMetadata
1431 1432 1433 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1431 def @get_version_operation_metadata end |
#http_error_message ⇒ String
[Output Only] If the operation fails, this field contains the HTTP error
message that was returned, such as NOT FOUND.
Corresponds to the JSON property httpErrorMessage
1437 1438 1439 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1437 def @http_error_message end |
#http_error_status_code ⇒ Fixnum
[Output Only] If the operation fails, this field contains the HTTP error
status code that was returned. For example, a 404 means the resource was not
found.
Corresponds to the JSON property httpErrorStatusCode
1444 1445 1446 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1444 def http_error_status_code @http_error_status_code end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the operation. This identifier is
defined by the server.
Corresponds to the JSON property id
1450 1451 1452 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1450 def id @id end |
#insert_time ⇒ String
[Output Only] The time that this operation was requested. This value is in
RFC3339 text format.
Corresponds to the JSON property insertTime
1456 1457 1458 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1456 def insert_time @insert_time end |
#instances_bulk_insert_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::InstancesBulkInsertOperationMetadata
Corresponds to the JSON property instancesBulkInsertOperationMetadata
1461 1462 1463 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1461 def @instances_bulk_insert_operation_metadata end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#operation
for Operation resources.
Corresponds to the JSON property kind
1467 1468 1469 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1467 def kind @kind end |
#name ⇒ String
[Output Only] Name of the operation.
Corresponds to the JSON property name
1472 1473 1474 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1472 def name @name end |
#operation_group_id ⇒ String
Output only. [Output Only] An ID that represents a group of operations, such
as when a group of operations results from a bulkInsert API request.
Corresponds to the JSON property operationGroupId
1478 1479 1480 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1478 def operation_group_id @operation_group_id end |
#operation_type ⇒ String
[Output Only] The type of operation, such as insert, update, or delete,
and so on.
Corresponds to the JSON property operationType
1484 1485 1486 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1484 def operation_type @operation_type end |
#progress ⇒ Fixnum
[Output Only] An optional progress indicator that ranges from 0 to 100. There
is no requirement that this be linear or support any granularity of operations.
This should not be used to guess when the operation will be complete. This
number should monotonically increase as the operation progresses.
Corresponds to the JSON property progress
1492 1493 1494 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1492 def progress @progress end |
#region ⇒ String
[Output Only] The URL of the region where the operation resides. Only
applicable when performing regional operations.
Corresponds to the JSON property region
1498 1499 1500 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1498 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
1503 1504 1505 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1503 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
1509 1510 1511 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1509 def self_link_with_id @self_link_with_id end |
#set_autoscaler_link_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::SetAutoscalerLinkOperationMetadata
This field is used internally by the Autoscaler team and should not be
promoted to "alpha/beta/v1".
Corresponds to the JSON property setAutoscalerLinkOperationMetadata
1515 1516 1517 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1515 def @set_autoscaler_link_operation_metadata end |
#set_common_instance_metadata_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::SetCommonInstanceMetadataOperationMetadata
Output only. [Output Only] If the operation is for projects.
setCommonInstanceMetadata, this field will contain information on all
underlying zonal actions and their state.
Corresponds to the JSON property setCommonInstanceMetadataOperationMetadata
1522 1523 1524 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1522 def @set_common_instance_metadata_operation_metadata end |
#start_time ⇒ String
[Output Only] The time that this operation was started by the server. This
value is in RFC3339 text format.
Corresponds to the JSON property startTime
1528 1529 1530 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1528 def start_time @start_time end |
#status ⇒ String
[Output Only] The status of the operation, which can be one of the following:
PENDING, RUNNING, or DONE.
Corresponds to the JSON property status
1534 1535 1536 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1534 def status @status end |
#status_message ⇒ String
[Output Only] An optional textual description of the current status of the
operation.
Corresponds to the JSON property statusMessage
1540 1541 1542 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1540 def @status_message end |
#target_id ⇒ Fixnum
[Output Only] The unique target ID, which identifies a specific incarnation of
the target resource.
Corresponds to the JSON property targetId
1546 1547 1548 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1546 def target_id @target_id end |
#target_link ⇒ String
[Output Only] The URL of the resource that the operation modifies. For
operations related to creating a snapshot, this points to the disk that the
snapshot was created from.
Corresponds to the JSON property targetLink
1553 1554 1555 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1553 def target_link @target_link end |
#user ⇒ String
[Output Only] User who requested the operation, for example: user@example.com
or alice_smith_identifier (global/workforcePools/example-com-us-employees).
Corresponds to the JSON property user
1559 1560 1561 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1559 def user @user end |
#warnings ⇒ Array<Google::Apis::DeploymentmanagerV2beta::Operation::Warning>
[Output Only] If warning messages are generated during processing of the
operation, this field will be populated.
Corresponds to the JSON property warnings
1565 1566 1567 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1565 def warnings @warnings end |
#zone ⇒ String
[Output Only] The URL of the zone where the operation resides. Only applicable
when performing per-zone operations.
Corresponds to the JSON property zone
1571 1572 1573 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1571 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1578 def update!(**args) @client_operation_id = args[:client_operation_id] if args.key?(:client_operation_id) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @firewall_policy_rule_operation_metadata = args[:firewall_policy_rule_operation_metadata] if args.key?(:firewall_policy_rule_operation_metadata) @get_version_operation_metadata = args[:get_version_operation_metadata] if args.key?(:get_version_operation_metadata) @http_error_message = args[:http_error_message] if args.key?(:http_error_message) @http_error_status_code = args[:http_error_status_code] if args.key?(:http_error_status_code) @id = args[:id] if args.key?(:id) @insert_time = args[:insert_time] if args.key?(:insert_time) @instances_bulk_insert_operation_metadata = args[:instances_bulk_insert_operation_metadata] if args.key?(:instances_bulk_insert_operation_metadata) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @operation_group_id = args[:operation_group_id] if args.key?(:operation_group_id) @operation_type = args[:operation_type] if args.key?(:operation_type) @progress = args[:progress] if args.key?(:progress) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @set_autoscaler_link_operation_metadata = args[:set_autoscaler_link_operation_metadata] if args.key?(:set_autoscaler_link_operation_metadata) @set_common_instance_metadata_operation_metadata = args[:set_common_instance_metadata_operation_metadata] if args.key?(:set_common_instance_metadata_operation_metadata) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) @target_id = args[:target_id] if args.key?(:target_id) @target_link = args[:target_link] if args.key?(:target_link) @user = args[:user] if args.key?(:user) @warnings = args[:warnings] if args.key?(:warnings) @zone = args[:zone] if args.key?(:zone) end |