Class: Google::Apis::DeploymentmanagerV2beta::Operation::Error::Error
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::Operation::Error::Error
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Defined Under Namespace
Classes: ErrorDetail
Instance Attribute Summary collapse
-
#arguments ⇒ Array<String>
Output only.
-
#code ⇒ String
[Output Only] The error type identifier for this error.
-
#debug_info ⇒ Google::Apis::DeploymentmanagerV2beta::DebugInfo
Describes additional debugging info.
-
#error_details ⇒ Array<Google::Apis::DeploymentmanagerV2beta::Operation::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error details.
-
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
-
#message ⇒ String
[Output Only] An optional, human-readable error message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Error
constructor
A new instance of Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Error
Returns a new instance of Error.
1671 1672 1673 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1671 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Array<String>
Output only. [Output Only] Optional error details WARNING: DO NOT MAKE VISIBLE
This is for internal use-only (like componentization) (thus the visibility "
none") and in case of public exposure it is strongly recommended to follow
pattern of: https://aip.dev/193 and expose as details field.
Corresponds to the JSON property arguments
1640 1641 1642 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1640 def arguments @arguments end |
#code ⇒ String
[Output Only] The error type identifier for this error.
Corresponds to the JSON property code
1645 1646 1647 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1645 def code @code end |
#debug_info ⇒ Google::Apis::DeploymentmanagerV2beta::DebugInfo
Describes additional debugging info.
Corresponds to the JSON property debugInfo
1650 1651 1652 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1650 def debug_info @debug_info end |
#error_details ⇒ Array<Google::Apis::DeploymentmanagerV2beta::Operation::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error details.
There is a set of defined message types to use for providing details.The
syntax depends on the error code. For example, QuotaExceededInfo will have
details when the error code is QUOTA_EXCEEDED.
Corresponds to the JSON property errorDetails
1658 1659 1660 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1658 def error_details @error_details end |
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error. This
property is optional.
Corresponds to the JSON property location
1664 1665 1666 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1664 def location @location end |
#message ⇒ String
[Output Only] An optional, human-readable error message.
Corresponds to the JSON property message
1669 1670 1671 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1669 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1676 1677 1678 1679 1680 1681 1682 1683 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1676 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @code = args[:code] if args.key?(:code) @debug_info = args[:debug_info] if args.key?(:debug_info) @error_details = args[:error_details] if args.key?(:error_details) @location = args[:location] if args.key?(:location) @message = args[:message] if args.key?(:message) end |