Class: Google::Apis::DeploymentmanagerV2beta::Operation::Warning::Datum
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::Operation::Warning::Datum
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Instance Attribute Summary collapse
-
#key ⇒ String
[Output Only] A key that provides more detail on the warning being returned.
-
#value ⇒ String
[Output Only] A warning data value corresponding to the key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Datum
constructor
A new instance of Datum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Datum
Returns a new instance of Datum.
1735 1736 1737 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1735 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
[Output Only] A key that provides more detail on the warning being returned.
For example, for warnings where there are no results in a list request for a
particular zone, this key might be scope and the key value might be the zone
name. Other examples might be a key indicating a deprecated resource and a
suggested replacement, or a warning about invalid network settings (for
example, if an instance attempts to perform IP forwarding but is not enabled
for IP forwarding).
Corresponds to the JSON property key
1728 1729 1730 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1728 def key @key end |
#value ⇒ String
[Output Only] A warning data value corresponding to the key.
Corresponds to the JSON property value
1733 1734 1735 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1733 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1740 1741 1742 1743 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1740 def update!(**args) @key = args[:key] if args.key?(:key) @value = args[:value] if args.key?(:value) end |