Class: Google::Apis::DeploymentmanagerV2beta::PollingOptions
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::PollingOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Instance Attribute Summary collapse
-
#diagnostics ⇒ Array<Google::Apis::DeploymentmanagerV2beta::Diagnostic>
An array of diagnostics to be collected by Deployment Manager, these diagnostics will be displayed to the user.
-
#fail_condition ⇒ String
JsonPath expression that determines if the request failed.
-
#finish_condition ⇒ String
JsonPath expression that determines if the request is completed.
-
#polling_link ⇒ String
JsonPath expression that evaluates to string, it indicates where to poll.
-
#target_link ⇒ String
JsonPath expression, after polling is completed, indicates where to fetch the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PollingOptions
constructor
A new instance of PollingOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PollingOptions
Returns a new instance of PollingOptions.
1995 1996 1997 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#diagnostics ⇒ Array<Google::Apis::DeploymentmanagerV2beta::Diagnostic>
An array of diagnostics to be collected by Deployment Manager, these
diagnostics will be displayed to the user.
Corresponds to the JSON property diagnostics
1972 1973 1974 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1972 def diagnostics @diagnostics end |
#fail_condition ⇒ String
JsonPath expression that determines if the request failed.
Corresponds to the JSON property failCondition
1977 1978 1979 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1977 def fail_condition @fail_condition end |
#finish_condition ⇒ String
JsonPath expression that determines if the request is completed.
Corresponds to the JSON property finishCondition
1982 1983 1984 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1982 def finish_condition @finish_condition end |
#polling_link ⇒ String
JsonPath expression that evaluates to string, it indicates where to poll.
Corresponds to the JSON property pollingLink
1987 1988 1989 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1987 def polling_link @polling_link end |
#target_link ⇒ String
JsonPath expression, after polling is completed, indicates where to fetch the
resource.
Corresponds to the JSON property targetLink
1993 1994 1995 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1993 def target_link @target_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2000 2001 2002 2003 2004 2005 2006 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2000 def update!(**args) @diagnostics = args[:diagnostics] if args.key?(:diagnostics) @fail_condition = args[:fail_condition] if args.key?(:fail_condition) @finish_condition = args[:finish_condition] if args.key?(:finish_condition) @polling_link = args[:polling_link] if args.key?(:polling_link) @target_link = args[:target_link] if args.key?(:target_link) end |