Class: Google::Apis::DeploymentmanagerV2beta::Resource
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#access_control ⇒ Google::Apis::DeploymentmanagerV2beta::ResourceAccessControl
The access controls set on the resource.
-
#final_properties ⇒ String
Output only.
-
#id ⇒ Fixnum
Corresponds to the JSON property
id. -
#insert_time ⇒ String
Output only.
-
#manifest ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#properties ⇒ String
Output only.
-
#type ⇒ String
Output only.
-
#update ⇒ Google::Apis::DeploymentmanagerV2beta::ResourceUpdate
Output only.
-
#update_time ⇒ String
Output only.
-
#url ⇒ String
Output only.
-
#warnings ⇒ Array<Google::Apis::DeploymentmanagerV2beta::Resource::Warning>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Resource
constructor
A new instance of Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Resource
Returns a new instance of Resource.
2130 2131 2132 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2130 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_control ⇒ Google::Apis::DeploymentmanagerV2beta::ResourceAccessControl
The access controls set on the resource.
Corresponds to the JSON property accessControl
2067 2068 2069 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2067 def access_control @access_control end |
#final_properties ⇒ String
Output only. The evaluated properties of the resource with references expanded.
Returned as serialized YAML.
Corresponds to the JSON property finalProperties
2073 2074 2075 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2073 def final_properties @final_properties end |
#id ⇒ Fixnum
Corresponds to the JSON property id
2078 2079 2080 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2078 def id @id end |
#insert_time ⇒ String
Output only. Creation timestamp in RFC3339 text format.
Corresponds to the JSON property insertTime
2083 2084 2085 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2083 def insert_time @insert_time end |
#manifest ⇒ String
Output only. URL of the manifest representing the current configuration of
this resource.
Corresponds to the JSON property manifest
2089 2090 2091 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2089 def manifest @manifest end |
#name ⇒ String
Output only. The name of the resource as it appears in the YAML config.
Corresponds to the JSON property name
2094 2095 2096 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2094 def name @name end |
#properties ⇒ String
Output only. The current properties of the resource before any references have
been filled in. Returned as serialized YAML.
Corresponds to the JSON property properties
2100 2101 2102 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2100 def properties @properties end |
#type ⇒ String
Output only. The type of the resource, for example compute.v1.instance, or
cloudfunctions.v1beta1.function.
Corresponds to the JSON property type
2106 2107 2108 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2106 def type @type end |
#update ⇒ Google::Apis::DeploymentmanagerV2beta::ResourceUpdate
Output only. If Deployment Manager is currently updating or previewing an
update to this resource, the updated configuration appears here.
Corresponds to the JSON property update
2112 2113 2114 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2112 def update @update end |
#update_time ⇒ String
Output only. Update timestamp in RFC3339 text format.
Corresponds to the JSON property updateTime
2117 2118 2119 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2117 def update_time @update_time end |
#url ⇒ String
Output only. The URL of the actual resource.
Corresponds to the JSON property url
2122 2123 2124 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2122 def url @url end |
#warnings ⇒ Array<Google::Apis::DeploymentmanagerV2beta::Resource::Warning>
Output only. If warning messages are generated during processing of this
resource, this field will be populated.
Corresponds to the JSON property warnings
2128 2129 2130 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2128 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2135 def update!(**args) @access_control = args[:access_control] if args.key?(:access_control) @final_properties = args[:final_properties] if args.key?(:final_properties) @id = args[:id] if args.key?(:id) @insert_time = args[:insert_time] if args.key?(:insert_time) @manifest = args[:manifest] if args.key?(:manifest) @name = args[:name] if args.key?(:name) @properties = args[:properties] if args.key?(:properties) @type = args[:type] if args.key?(:type) @update = args[:update] if args.key?(:update) @update_time = args[:update_time] if args.key?(:update_time) @url = args[:url] if args.key?(:url) @warnings = args[:warnings] if args.key?(:warnings) end |