Class: Google::Apis::DeploymentmanagerV2beta::ResourceUpdate::Error::Error
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::ResourceUpdate::Error::Error
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Defined Under Namespace
Classes: ErrorDetail
Instance Attribute Summary collapse
-
#arguments ⇒ Array<String>
Output only.
-
#code ⇒ String
[Output Only] The error type identifier for this error.
-
#debug_info ⇒ Google::Apis::DeploymentmanagerV2beta::DebugInfo
Describes additional debugging info.
-
#error_details ⇒ Array<Google::Apis::DeploymentmanagerV2beta::ResourceUpdate::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error details.
-
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
-
#message ⇒ String
[Output Only] An optional, human-readable error message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Error
constructor
A new instance of Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Error
Returns a new instance of Error.
2307 2308 2309 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2307 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Array<String>
Output only. [Output Only] Optional error details WARNING: DO NOT MAKE VISIBLE
This is for internal use-only (like componentization) (thus the visibility "
none") and in case of public exposure it is strongly recommended to follow
pattern of: https://aip.dev/193 and expose as details field.
Corresponds to the JSON property arguments
2276 2277 2278 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2276 def arguments @arguments end |
#code ⇒ String
[Output Only] The error type identifier for this error.
Corresponds to the JSON property code
2281 2282 2283 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2281 def code @code end |
#debug_info ⇒ Google::Apis::DeploymentmanagerV2beta::DebugInfo
Describes additional debugging info.
Corresponds to the JSON property debugInfo
2286 2287 2288 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2286 def debug_info @debug_info end |
#error_details ⇒ Array<Google::Apis::DeploymentmanagerV2beta::ResourceUpdate::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error details.
There is a set of defined message types to use for providing details.The
syntax depends on the error code. For example, QuotaExceededInfo will have
details when the error code is QUOTA_EXCEEDED.
Corresponds to the JSON property errorDetails
2294 2295 2296 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2294 def error_details @error_details end |
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error. This
property is optional.
Corresponds to the JSON property location
2300 2301 2302 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2300 def location @location end |
#message ⇒ String
[Output Only] An optional, human-readable error message.
Corresponds to the JSON property message
2305 2306 2307 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2305 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2312 2313 2314 2315 2316 2317 2318 2319 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2312 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @code = args[:code] if args.key?(:code) @debug_info = args[:debug_info] if args.key?(:debug_info) @error_details = args[:error_details] if args.key?(:error_details) @location = args[:location] if args.key?(:location) @message = args[:message] if args.key?(:message) end |