Class: Google::Apis::DeploymentmanagerV2beta::ResourceUpdate::Error::Error::ErrorDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ErrorDetail

Returns a new instance of ErrorDetail.



2408
2409
2410
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_infoGoogle::Apis::DeploymentmanagerV2beta::ErrorInfo

Describes the cause of the error with structured details. Example of an error when contacting the "pubsub.googleapis.com" API when it is not enabled: " reason": "API_DISABLED" "domain": "googleapis.com" "metadata": "resource": " projects/123", "service": "pubsub.googleapis.com" This response indicates that the pubsub.googleapis.com API is not enabled. Example of an error that is returned when attempting to create a Spanner instance in a region that is out of stock: "reason": "STOCKOUT" "domain": "spanner.googleapis.com", "metadata" : "availableRegions": "us-central1,us-east2" Corresponds to the JSON property errorInfo



2387
2388
2389
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2387

def error_info
  @error_info
end

#helpGoogle::Apis::DeploymentmanagerV2beta::Help

Provides links to documentation or for performing an out of band action. For example, if a quota check failed with an error indicating the calling project hasn't enabled the accessed service, this can contain a URL pointing directly to the right place in the developer console to flip the bit. Corresponds to the JSON property help



2395
2396
2397
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2395

def help
  @help
end

#localized_messageGoogle::Apis::DeploymentmanagerV2beta::LocalizedMessage

Provides a localized error message that is safe to return to the user which can be attached to an RPC error. Corresponds to the JSON property localizedMessage



2401
2402
2403
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2401

def localized_message
  @localized_message
end

#quota_infoGoogle::Apis::DeploymentmanagerV2beta::QuotaExceededInfo

Additional details for quota exceeded error for resource quota. Corresponds to the JSON property quotaInfo



2406
2407
2408
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2406

def quota_info
  @quota_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2413
2414
2415
2416
2417
2418
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2413

def update!(**args)
  @error_info = args[:error_info] if args.key?(:error_info)
  @help = args[:help] if args.key?(:help)
  @localized_message = args[:localized_message] if args.key?(:localized_message)
  @quota_info = args[:quota_info] if args.key?(:quota_info)
end