Class: Google::Apis::DeploymentmanagerV2beta::ResourceUpdate::Warning::Datum
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::ResourceUpdate::Warning::Datum
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Instance Attribute Summary collapse
-
#key ⇒ String
[Output Only] A key that provides more detail on the warning being returned.
-
#value ⇒ String
[Output Only] A warning data value corresponding to the key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Datum
constructor
A new instance of Datum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Datum
Returns a new instance of Datum.
2423 2424 2425 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2423 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
[Output Only] A key that provides more detail on the warning being returned.
For example, for warnings where there are no results in a list request for a
particular zone, this key might be scope and the key value might be the zone
name. Other examples might be a key indicating a deprecated resource and a
suggested replacement, or a warning about invalid network settings (for
example, if an instance attempts to perform IP forwarding but is not enabled
for IP forwarding).
Corresponds to the JSON property key
2416 2417 2418 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2416 def key @key end |
#value ⇒ String
[Output Only] A warning data value corresponding to the key.
Corresponds to the JSON property value
2421 2422 2423 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2421 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2428 2429 2430 2431 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2428 def update!(**args) @key = args[:key] if args.key?(:key) @value = args[:value] if args.key?(:value) end |