Class: Google::Apis::DeploymentmanagerV2beta::Type

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb

Overview

A resource type supported by Deployment Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Type

Returns a new instance of Type.



2771
2772
2773
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#baseGoogle::Apis::DeploymentmanagerV2beta::BaseType

BaseType that describes a service-backed Type. Corresponds to the JSON property base



2719
2720
2721
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2719

def base
  @base
end

#descriptionString

An optional textual description of the resource; provided by the client when the resource is created. Corresponds to the JSON property description

Returns:

  • (String)


2725
2726
2727
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2725

def description
  @description
end

#idFixnum

Corresponds to the JSON property id

Returns:

  • (Fixnum)


2730
2731
2732
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2730

def id
  @id
end

#insert_timeString

Output only. Creation timestamp in RFC3339 text format. Corresponds to the JSON property insertTime

Returns:

  • (String)


2735
2736
2737
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2735

def insert_time
  @insert_time
end

#labelsArray<Google::Apis::DeploymentmanagerV2beta::TypeLabelEntry>

Map of One Platform labels; provided by the client when the resource is created or updated. Specifically: Label keys must be between 1 and 63 characters long and must conform to the following regular expression: [a-z]([- a-z0-9]*[a-z0-9])? Label values must be between 0 and 63 characters long and must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)?. Corresponds to the JSON property labels



2744
2745
2746
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2744

def labels
  @labels
end

#nameString

Name of the type. Corresponds to the JSON property name

Returns:

  • (String)


2749
2750
2751
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2749

def name
  @name
end

#operationGoogle::Apis::DeploymentmanagerV2beta::Operation

Represents an Operation resource. Google Compute Engine has three Operation resources: * Global * Regional * Zonal You can use an operation resource to manage asynchronous API requests. For more information, read Handling API responses. Operations can be global, regional or zonal. - For global operations, use the globalOperations resource. - For regional operations, use the regionOperations resource. - For zonal operations, use the zoneOperations resource. For more information, read Global, Regional, and Zonal Resources. Note that completed Operation resources have a limited retention period. Corresponds to the JSON property operation



2764
2765
2766
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2764

def operation
  @operation
end

Output only. Server defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2769
2770
2771
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2769

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2776

def update!(**args)
  @base = args[:base] if args.key?(:base)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @insert_time = args[:insert_time] if args.key?(:insert_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @operation = args[:operation] if args.key?(:operation)
  @self_link = args[:self_link] if args.key?(:self_link)
end