Class: Google::Apis::DeploymentmanagerV2beta::TypeInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb

Overview

Type Information. Contains detailed information about a composite type, base type, or base type with specific collection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TypeInfo

Returns a new instance of TypeInfo.



2883
2884
2885
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2883

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

The description of the type. Corresponds to the JSON property description

Returns:

  • (String)


2848
2849
2850
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2848

def description
  @description
end

For swagger 2.0 externalDocs field will be used. For swagger 1.2 this field will be empty. Corresponds to the JSON property documentationLink

Returns:

  • (String)


2854
2855
2856
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2854

def documentation_link
  @documentation_link
end

#kindString

Output only. Type of the output. Always deploymentManager#TypeInfo for TypeInfo. Corresponds to the JSON property kind

Returns:

  • (String)


2860
2861
2862
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2860

def kind
  @kind
end

#nameString

The base type or composite type name. Corresponds to the JSON property name

Returns:

  • (String)


2865
2866
2867
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2865

def name
  @name
end

#schemaGoogle::Apis::DeploymentmanagerV2beta::TypeInfoSchemaInfo

For base types with a collection, we return a schema and documentation link For template types, we return only a schema Corresponds to the JSON property schema



2871
2872
2873
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2871

def schema
  @schema
end

Output only. Self link for the type provider. Corresponds to the JSON property selfLink

Returns:

  • (String)


2876
2877
2878
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2876

def self_link
  @self_link
end

#titleString

The title on the API descriptor URL provided. Corresponds to the JSON property title

Returns:

  • (String)


2881
2882
2883
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2881

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2888
2889
2890
2891
2892
2893
2894
2895
2896
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2888

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @documentation_link = args[:documentation_link] if args.key?(:documentation_link)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @schema = args[:schema] if args.key?(:schema)
  @self_link = args[:self_link] if args.key?(:self_link)
  @title = args[:title] if args.key?(:title)
end