Class: Google::Apis::DeploymentmanagerV2beta::TypeProvider

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb

Overview

A type provider that describes a service-backed Type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TypeProvider

Returns a new instance of TypeProvider.



3042
3043
3044
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 3042

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_overridesArray<Google::Apis::DeploymentmanagerV2beta::CollectionOverride>

Allows resource handling overrides for specific collections Corresponds to the JSON property collectionOverrides



2959
2960
2961
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2959

def collection_overrides
  @collection_overrides
end

#credentialGoogle::Apis::DeploymentmanagerV2beta::Credential

The credential used by Deployment Manager and TypeProvider. Only one of the options is permitted. Corresponds to the JSON property credential



2965
2966
2967
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2965

def credential
  @credential
end

#custom_certificate_authority_rootsArray<String>

List of up to 2 custom certificate authority roots to use for TLS authentication when making calls on behalf of this type provider. If set, TLS authentication will exclusively use these roots instead of relying on publicly trusted certificate authorities when validating TLS certificate authenticity. The certificates must be in base64-encoded PEM format. The maximum size of each certificate must not exceed 10KB. Corresponds to the JSON property customCertificateAuthorityRoots

Returns:

  • (Array<String>)


2975
2976
2977
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2975

def custom_certificate_authority_roots
  @custom_certificate_authority_roots
end

#descriptionString

An optional textual description of the resource; provided by the client when the resource is created. Corresponds to the JSON property description

Returns:

  • (String)


2981
2982
2983
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2981

def description
  @description
end

#descriptor_urlString

Descriptor Url for the this type provider. Corresponds to the JSON property descriptorUrl

Returns:

  • (String)


2986
2987
2988
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2986

def descriptor_url
  @descriptor_url
end

#idFixnum

Output only. Unique identifier for the resource defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


2991
2992
2993
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2991

def id
  @id
end

#insert_timeString

Output only. Creation timestamp in RFC3339 text format. Corresponds to the JSON property insertTime

Returns:

  • (String)


2996
2997
2998
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2996

def insert_time
  @insert_time
end

#labelsArray<Google::Apis::DeploymentmanagerV2beta::TypeProviderLabelEntry>

Map of One Platform labels; provided by the client when the resource is created or updated. Specifically: Label keys must be between 1 and 63 characters long and must conform to the following regular expression: [a-z]([- a-z0-9]*[a-z0-9])? Label values must be between 0 and 63 characters long and must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)? Corresponds to the JSON property labels



3005
3006
3007
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 3005

def labels
  @labels
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a- z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


3015
3016
3017
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 3015

def name
  @name
end

#operationGoogle::Apis::DeploymentmanagerV2beta::Operation

Represents an Operation resource. Google Compute Engine has three Operation resources: * Global * Regional * Zonal You can use an operation resource to manage asynchronous API requests. For more information, read Handling API responses. Operations can be global, regional or zonal. - For global operations, use the globalOperations resource. - For regional operations, use the regionOperations resource. - For zonal operations, use the zoneOperations resource. For more information, read Global, Regional, and Zonal Resources. Note that completed Operation resources have a limited retention period. Corresponds to the JSON property operation



3030
3031
3032
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 3030

def operation
  @operation
end

#optionsGoogle::Apis::DeploymentmanagerV2beta::Options

Options allows customized resource handling by Deployment Manager. Corresponds to the JSON property options



3035
3036
3037
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 3035

def options
  @options
end

Output only. Self link for the type provider. Corresponds to the JSON property selfLink

Returns:

  • (String)


3040
3041
3042
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 3040

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3047
3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 3047

def update!(**args)
  @collection_overrides = args[:collection_overrides] if args.key?(:collection_overrides)
  @credential = args[:credential] if args.key?(:credential)
  @custom_certificate_authority_roots = args[:custom_certificate_authority_roots] if args.key?(:custom_certificate_authority_roots)
  @description = args[:description] if args.key?(:description)
  @descriptor_url = args[:descriptor_url] if args.key?(:descriptor_url)
  @id = args[:id] if args.key?(:id)
  @insert_time = args[:insert_time] if args.key?(:insert_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @operation = args[:operation] if args.key?(:operation)
  @options = args[:options] if args.key?(:options)
  @self_link = args[:self_link] if args.key?(:self_link)
end