Class: Google::Apis::DeploymentmanagerV2beta::Operation
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::Operation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Overview
Represents an Operation resource. Google Compute Engine has three Operation
resources: * Global * Regional * Zonal You can use an operation resource to manage asynchronous API
requests. For more information, read Handling API responses. Operations can be
global, regional or zonal. - For global operations, use the globalOperations
resource. - For regional operations, use the regionOperations resource. -
For zonal operations, use the zoneOperations resource. For more information,
read Global, Regional, and Zonal Resources. Note that completed Operation
resources have a limited retention period.
Defined Under Namespace
Instance Attribute Summary collapse
-
#client_operation_id ⇒ String
[Output Only] The value of
requestIdif you provided it in the request. -
#creation_timestamp ⇒ String
[Deprecated] This field is deprecated.
-
#description ⇒ String
[Output Only] A textual description of the operation, which is set when the operation is created.
-
#end_time ⇒ String
[Output Only] The time that this operation was completed.
-
#error ⇒ Google::Apis::DeploymentmanagerV2beta::Operation::Error
[Output Only] If errors are generated during processing of the operation, this field will be populated.
-
#firewall_policy_rule_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::FirewallPolicyRuleOperationMetadata
Corresponds to the JSON property
firewallPolicyRuleOperationMetadata. -
#http_error_message ⇒ String
[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as
NOT FOUND. -
#http_error_status_code ⇒ Fixnum
[Output Only] If the operation fails, this field contains the HTTP error status code that was returned.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the operation.
-
#insert_time ⇒ String
[Output Only] The time that this operation was requested.
-
#instances_bulk_insert_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::InstancesBulkInsertOperationMetadata
Corresponds to the JSON property
instancesBulkInsertOperationMetadata. -
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the operation.
-
#operation_group_id ⇒ String
Output only.
-
#operation_type ⇒ String
[Output Only] The type of operation, such as
insert,update, ordelete, and so on. -
#progress ⇒ Fixnum
[Output Only] An optional progress indicator that ranges from 0 to 100.
-
#region ⇒ String
[Output Only] The URL of the region where the operation resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#set_autoscaler_link_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::SetAutoscalerLinkOperationMetadata
This field is used internally by the Autoscaler team and should not be promoted to "alpha/beta/v1".
-
#set_common_instance_metadata_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::SetCommonInstanceMetadataOperationMetadata
Output only.
-
#start_time ⇒ String
[Output Only] The time that this operation was started by the server.
-
#status ⇒ String
[Output Only] The status of the operation, which can be one of the following:
PENDING,RUNNING, orDONE. -
#status_message ⇒ String
[Output Only] An optional textual description of the current status of the operation.
-
#target_id ⇒ Fixnum
[Output Only] The unique target ID, which identifies a specific incarnation of the target resource.
-
#target_link ⇒ String
[Output Only] The URL of the resource that the operation modifies.
-
#user ⇒ String
[Output Only] User who requested the operation, for example:
user@example.comoralice_smith_identifier (global/workforcePools/example-com-us-employees). -
#warnings ⇒ Array<Google::Apis::DeploymentmanagerV2beta::Operation::Warning>
[Output Only] If warning messages are generated during processing of the operation, this field will be populated.
-
#zone ⇒ String
[Output Only] The URL of the zone where the operation resides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Operation
constructor
A new instance of Operation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Operation
Returns a new instance of Operation.
1522 1523 1524 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1522 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_operation_id ⇒ String
[Output Only] The value of requestId if you provided it in the request. Not
present otherwise.
Corresponds to the JSON property clientOperationId
1352 1353 1354 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1352 def client_operation_id @client_operation_id end |
#creation_timestamp ⇒ String
[Deprecated] This field is deprecated.
Corresponds to the JSON property creationTimestamp
1357 1358 1359 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1357 def @creation_timestamp end |
#description ⇒ String
[Output Only] A textual description of the operation, which is set when the
operation is created.
Corresponds to the JSON property description
1363 1364 1365 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1363 def description @description end |
#end_time ⇒ String
[Output Only] The time that this operation was completed. This value is in
RFC3339 text format.
Corresponds to the JSON property endTime
1369 1370 1371 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1369 def end_time @end_time end |
#error ⇒ Google::Apis::DeploymentmanagerV2beta::Operation::Error
[Output Only] If errors are generated during processing of the operation, this
field will be populated.
Corresponds to the JSON property error
1375 1376 1377 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1375 def error @error end |
#firewall_policy_rule_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::FirewallPolicyRuleOperationMetadata
Corresponds to the JSON property firewallPolicyRuleOperationMetadata
1380 1381 1382 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1380 def @firewall_policy_rule_operation_metadata end |
#http_error_message ⇒ String
[Output Only] If the operation fails, this field contains the HTTP error
message that was returned, such as NOT FOUND.
Corresponds to the JSON property httpErrorMessage
1386 1387 1388 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1386 def @http_error_message end |
#http_error_status_code ⇒ Fixnum
[Output Only] If the operation fails, this field contains the HTTP error
status code that was returned. For example, a 404 means the resource was not
found.
Corresponds to the JSON property httpErrorStatusCode
1393 1394 1395 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1393 def http_error_status_code @http_error_status_code end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the operation. This identifier is
defined by the server.
Corresponds to the JSON property id
1399 1400 1401 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1399 def id @id end |
#insert_time ⇒ String
[Output Only] The time that this operation was requested. This value is in
RFC3339 text format.
Corresponds to the JSON property insertTime
1405 1406 1407 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1405 def insert_time @insert_time end |
#instances_bulk_insert_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::InstancesBulkInsertOperationMetadata
Corresponds to the JSON property instancesBulkInsertOperationMetadata
1410 1411 1412 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1410 def @instances_bulk_insert_operation_metadata end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#operation
for Operation resources.
Corresponds to the JSON property kind
1416 1417 1418 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1416 def kind @kind end |
#name ⇒ String
[Output Only] Name of the operation.
Corresponds to the JSON property name
1421 1422 1423 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1421 def name @name end |
#operation_group_id ⇒ String
Output only. [Output Only] An ID that represents a group of operations, such
as when a group of operations results from a bulkInsert API request.
Corresponds to the JSON property operationGroupId
1427 1428 1429 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1427 def operation_group_id @operation_group_id end |
#operation_type ⇒ String
[Output Only] The type of operation, such as insert, update, or delete,
and so on.
Corresponds to the JSON property operationType
1433 1434 1435 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1433 def operation_type @operation_type end |
#progress ⇒ Fixnum
[Output Only] An optional progress indicator that ranges from 0 to 100. There
is no requirement that this be linear or support any granularity of operations.
This should not be used to guess when the operation will be complete. This
number should monotonically increase as the operation progresses.
Corresponds to the JSON property progress
1441 1442 1443 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1441 def progress @progress end |
#region ⇒ String
[Output Only] The URL of the region where the operation resides. Only
applicable when performing regional operations.
Corresponds to the JSON property region
1447 1448 1449 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1447 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
1452 1453 1454 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1452 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
1458 1459 1460 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1458 def self_link_with_id @self_link_with_id end |
#set_autoscaler_link_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::SetAutoscalerLinkOperationMetadata
This field is used internally by the Autoscaler team and should not be
promoted to "alpha/beta/v1".
Corresponds to the JSON property setAutoscalerLinkOperationMetadata
1464 1465 1466 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1464 def @set_autoscaler_link_operation_metadata end |
#set_common_instance_metadata_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2beta::SetCommonInstanceMetadataOperationMetadata
Output only. [Output Only] If the operation is for projects.
setCommonInstanceMetadata, this field will contain information on all
underlying zonal actions and their state.
Corresponds to the JSON property setCommonInstanceMetadataOperationMetadata
1471 1472 1473 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1471 def @set_common_instance_metadata_operation_metadata end |
#start_time ⇒ String
[Output Only] The time that this operation was started by the server. This
value is in RFC3339 text format.
Corresponds to the JSON property startTime
1477 1478 1479 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1477 def start_time @start_time end |
#status ⇒ String
[Output Only] The status of the operation, which can be one of the following:
PENDING, RUNNING, or DONE.
Corresponds to the JSON property status
1483 1484 1485 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1483 def status @status end |
#status_message ⇒ String
[Output Only] An optional textual description of the current status of the
operation.
Corresponds to the JSON property statusMessage
1489 1490 1491 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1489 def @status_message end |
#target_id ⇒ Fixnum
[Output Only] The unique target ID, which identifies a specific incarnation of
the target resource.
Corresponds to the JSON property targetId
1495 1496 1497 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1495 def target_id @target_id end |
#target_link ⇒ String
[Output Only] The URL of the resource that the operation modifies. For
operations related to creating a snapshot, this points to the disk that the
snapshot was created from.
Corresponds to the JSON property targetLink
1502 1503 1504 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1502 def target_link @target_link end |
#user ⇒ String
[Output Only] User who requested the operation, for example: user@example.com
or alice_smith_identifier (global/workforcePools/example-com-us-employees).
Corresponds to the JSON property user
1508 1509 1510 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1508 def user @user end |
#warnings ⇒ Array<Google::Apis::DeploymentmanagerV2beta::Operation::Warning>
[Output Only] If warning messages are generated during processing of the
operation, this field will be populated.
Corresponds to the JSON property warnings
1514 1515 1516 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1514 def warnings @warnings end |
#zone ⇒ String
[Output Only] The URL of the zone where the operation resides. Only applicable
when performing per-zone operations.
Corresponds to the JSON property zone
1520 1521 1522 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1520 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1527 def update!(**args) @client_operation_id = args[:client_operation_id] if args.key?(:client_operation_id) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @firewall_policy_rule_operation_metadata = args[:firewall_policy_rule_operation_metadata] if args.key?(:firewall_policy_rule_operation_metadata) @http_error_message = args[:http_error_message] if args.key?(:http_error_message) @http_error_status_code = args[:http_error_status_code] if args.key?(:http_error_status_code) @id = args[:id] if args.key?(:id) @insert_time = args[:insert_time] if args.key?(:insert_time) @instances_bulk_insert_operation_metadata = args[:instances_bulk_insert_operation_metadata] if args.key?(:instances_bulk_insert_operation_metadata) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @operation_group_id = args[:operation_group_id] if args.key?(:operation_group_id) @operation_type = args[:operation_type] if args.key?(:operation_type) @progress = args[:progress] if args.key?(:progress) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @set_autoscaler_link_operation_metadata = args[:set_autoscaler_link_operation_metadata] if args.key?(:set_autoscaler_link_operation_metadata) @set_common_instance_metadata_operation_metadata = args[:set_common_instance_metadata_operation_metadata] if args.key?(:set_common_instance_metadata_operation_metadata) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) @target_id = args[:target_id] if args.key?(:target_id) @target_link = args[:target_link] if args.key?(:target_link) @user = args[:user] if args.key?(:user) @warnings = args[:warnings] if args.key?(:warnings) @zone = args[:zone] if args.key?(:zone) end |