Class: Google::Apis::DeploymentmanagerV2beta::Operation::Error::Error
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::Operation::Error::Error
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Defined Under Namespace
Classes: ErrorDetail
Instance Attribute Summary collapse
-
#arguments ⇒ Array<String>
Output only.
-
#code ⇒ String
[Output Only] The error type identifier for this error.
-
#debug_info ⇒ Google::Apis::DeploymentmanagerV2beta::DebugInfo
Describes additional debugging info.
-
#error_details ⇒ Array<Google::Apis::DeploymentmanagerV2beta::Operation::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error details.
-
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
-
#message ⇒ String
[Output Only] An optional, human-readable error message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Error
constructor
A new instance of Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Error
Returns a new instance of Error.
1619 1620 1621 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1619 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Array<String>
Output only. [Output Only] Optional error details WARNING: DO NOT MAKE VISIBLE
This is for internal use-only (like componentization) (thus the visibility "
none") and in case of public exposure it is strongly recommended to follow
pattern of: https://aip.dev/193 and expose as details field.
Corresponds to the JSON property arguments
1588 1589 1590 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1588 def arguments @arguments end |
#code ⇒ String
[Output Only] The error type identifier for this error.
Corresponds to the JSON property code
1593 1594 1595 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1593 def code @code end |
#debug_info ⇒ Google::Apis::DeploymentmanagerV2beta::DebugInfo
Describes additional debugging info.
Corresponds to the JSON property debugInfo
1598 1599 1600 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1598 def debug_info @debug_info end |
#error_details ⇒ Array<Google::Apis::DeploymentmanagerV2beta::Operation::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error details.
There is a set of defined message types to use for providing details.The
syntax depends on the error code. For example, QuotaExceededInfo will have
details when the error code is QUOTA_EXCEEDED.
Corresponds to the JSON property errorDetails
1606 1607 1608 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1606 def error_details @error_details end |
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error. This
property is optional.
Corresponds to the JSON property location
1612 1613 1614 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1612 def location @location end |
#message ⇒ String
[Output Only] An optional, human-readable error message.
Corresponds to the JSON property message
1617 1618 1619 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1617 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1624 1625 1626 1627 1628 1629 1630 1631 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 1624 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @code = args[:code] if args.key?(:code) @debug_info = args[:debug_info] if args.key?(:debug_info) @error_details = args[:error_details] if args.key?(:error_details) @location = args[:location] if args.key?(:location) @message = args[:message] if args.key?(:message) end |