Class: Google::Apis::DeploymentmanagerV2beta::Resource
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#access_control ⇒ Google::Apis::DeploymentmanagerV2beta::ResourceAccessControl
The access controls set on the resource.
-
#final_properties ⇒ String
Output only.
-
#id ⇒ Fixnum
Corresponds to the JSON property
id. -
#insert_time ⇒ String
Output only.
-
#manifest ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#properties ⇒ String
Output only.
-
#type ⇒ String
Output only.
-
#update ⇒ Google::Apis::DeploymentmanagerV2beta::ResourceUpdate
Output only.
-
#update_time ⇒ String
Output only.
-
#url ⇒ String
Output only.
-
#warnings ⇒ Array<Google::Apis::DeploymentmanagerV2beta::Resource::Warning>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Resource
constructor
A new instance of Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Resource
Returns a new instance of Resource.
2078 2079 2080 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2078 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_control ⇒ Google::Apis::DeploymentmanagerV2beta::ResourceAccessControl
The access controls set on the resource.
Corresponds to the JSON property accessControl
2015 2016 2017 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2015 def access_control @access_control end |
#final_properties ⇒ String
Output only. The evaluated properties of the resource with references expanded.
Returned as serialized YAML.
Corresponds to the JSON property finalProperties
2021 2022 2023 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2021 def final_properties @final_properties end |
#id ⇒ Fixnum
Corresponds to the JSON property id
2026 2027 2028 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2026 def id @id end |
#insert_time ⇒ String
Output only. Creation timestamp in RFC3339 text format.
Corresponds to the JSON property insertTime
2031 2032 2033 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2031 def insert_time @insert_time end |
#manifest ⇒ String
Output only. URL of the manifest representing the current configuration of
this resource.
Corresponds to the JSON property manifest
2037 2038 2039 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2037 def manifest @manifest end |
#name ⇒ String
Output only. The name of the resource as it appears in the YAML config.
Corresponds to the JSON property name
2042 2043 2044 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2042 def name @name end |
#properties ⇒ String
Output only. The current properties of the resource before any references have
been filled in. Returned as serialized YAML.
Corresponds to the JSON property properties
2048 2049 2050 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2048 def properties @properties end |
#type ⇒ String
Output only. The type of the resource, for example compute.v1.instance, or
cloudfunctions.v1beta1.function.
Corresponds to the JSON property type
2054 2055 2056 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2054 def type @type end |
#update ⇒ Google::Apis::DeploymentmanagerV2beta::ResourceUpdate
Output only. If Deployment Manager is currently updating or previewing an
update to this resource, the updated configuration appears here.
Corresponds to the JSON property update
2060 2061 2062 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2060 def update @update end |
#update_time ⇒ String
Output only. Update timestamp in RFC3339 text format.
Corresponds to the JSON property updateTime
2065 2066 2067 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2065 def update_time @update_time end |
#url ⇒ String
Output only. The URL of the actual resource.
Corresponds to the JSON property url
2070 2071 2072 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2070 def url @url end |
#warnings ⇒ Array<Google::Apis::DeploymentmanagerV2beta::Resource::Warning>
Output only. If warning messages are generated during processing of this
resource, this field will be populated.
Corresponds to the JSON property warnings
2076 2077 2078 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2076 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2083 def update!(**args) @access_control = args[:access_control] if args.key?(:access_control) @final_properties = args[:final_properties] if args.key?(:final_properties) @id = args[:id] if args.key?(:id) @insert_time = args[:insert_time] if args.key?(:insert_time) @manifest = args[:manifest] if args.key?(:manifest) @name = args[:name] if args.key?(:name) @properties = args[:properties] if args.key?(:properties) @type = args[:type] if args.key?(:type) @update = args[:update] if args.key?(:update) @update_time = args[:update_time] if args.key?(:update_time) @url = args[:url] if args.key?(:url) @warnings = args[:warnings] if args.key?(:warnings) end |