Class: Google::Apis::DeploymentmanagerV2beta::ResourceUpdate
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::ResourceUpdate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_control ⇒ Google::Apis::DeploymentmanagerV2beta::ResourceAccessControl
The access controls set on the resource.
-
#error ⇒ Google::Apis::DeploymentmanagerV2beta::ResourceUpdate::Error
Output only.
-
#final_properties ⇒ String
Output only.
-
#intent ⇒ String
Output only.
-
#manifest ⇒ String
Output only.
-
#properties ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#warnings ⇒ Array<Google::Apis::DeploymentmanagerV2beta::ResourceUpdate::Warning>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceUpdate
constructor
A new instance of ResourceUpdate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceUpdate
Returns a new instance of ResourceUpdate.
2231 2232 2233 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2231 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_control ⇒ Google::Apis::DeploymentmanagerV2beta::ResourceAccessControl
The access controls set on the resource.
Corresponds to the JSON property accessControl
2189 2190 2191 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2189 def access_control @access_control end |
#error ⇒ Google::Apis::DeploymentmanagerV2beta::ResourceUpdate::Error
Output only. If errors are generated during update of the resource, this field
will be populated.
Corresponds to the JSON property error
2195 2196 2197 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2195 def error @error end |
#final_properties ⇒ String
Output only. The expanded properties of the resource with reference values
expanded. Returned as serialized YAML.
Corresponds to the JSON property finalProperties
2201 2202 2203 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2201 def final_properties @final_properties end |
#intent ⇒ String
Output only. The intent of the resource: PREVIEW, UPDATE, or CANCEL.
Corresponds to the JSON property intent
2206 2207 2208 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2206 def intent @intent end |
#manifest ⇒ String
Output only. URL of the manifest representing the update configuration of this
resource.
Corresponds to the JSON property manifest
2212 2213 2214 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2212 def manifest @manifest end |
#properties ⇒ String
Output only. The set of updated properties for this resource, before
references are expanded. Returned as serialized YAML.
Corresponds to the JSON property properties
2218 2219 2220 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2218 def properties @properties end |
#state ⇒ String
Output only. The state of the resource.
Corresponds to the JSON property state
2223 2224 2225 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2223 def state @state end |
#warnings ⇒ Array<Google::Apis::DeploymentmanagerV2beta::ResourceUpdate::Warning>
Output only. If warning messages are generated during processing of this
resource, this field will be populated.
Corresponds to the JSON property warnings
2229 2230 2231 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2229 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2236 def update!(**args) @access_control = args[:access_control] if args.key?(:access_control) @error = args[:error] if args.key?(:error) @final_properties = args[:final_properties] if args.key?(:final_properties) @intent = args[:intent] if args.key?(:intent) @manifest = args[:manifest] if args.key?(:manifest) @properties = args[:properties] if args.key?(:properties) @state = args[:state] if args.key?(:state) @warnings = args[:warnings] if args.key?(:warnings) end |