Class: Google::Apis::DeploymentmanagerV2beta::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::DeploymentmanagerV2beta::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#state ⇒ String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING,PROPAGATED,ABANDONED,FAILED, orDONE.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
constructor
A new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
Returns a new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.
2553 2554 2555 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::DeploymentmanagerV2beta::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
2545 2546 2547 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2545 def error @error end |
#state ⇒ String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE.
Corresponds to the JSON property state
2551 2552 2553 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2551 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2558 2559 2560 2561 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2558 def update!(**args) @error = args[:error] if args.key?(:error) @state = args[:state] if args.key?(:state) end |