Class: Google::Apis::DeploymentmanagerV2beta::TypeInfo
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::TypeInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Overview
Type Information. Contains detailed information about a composite type, base type, or base type with specific collection.
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the type.
-
#documentation_link ⇒ String
For swagger 2.0 externalDocs field will be used.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The base type or composite type name.
-
#schema ⇒ Google::Apis::DeploymentmanagerV2beta::TypeInfoSchemaInfo
For base types with a collection, we return a schema and documentation link For template types, we return only a schema Corresponds to the JSON property
schema. -
#self_link ⇒ String
Output only.
-
#title ⇒ String
The title on the API descriptor URL provided.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TypeInfo
constructor
A new instance of TypeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TypeInfo
Returns a new instance of TypeInfo.
2831 2832 2833 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
The description of the type.
Corresponds to the JSON property description
2796 2797 2798 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2796 def description @description end |
#documentation_link ⇒ String
For swagger 2.0 externalDocs field will be used. For swagger 1.2 this field
will be empty.
Corresponds to the JSON property documentationLink
2802 2803 2804 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2802 def documentation_link @documentation_link end |
#kind ⇒ String
Output only. Type of the output. Always deploymentManager#TypeInfo for
TypeInfo.
Corresponds to the JSON property kind
2808 2809 2810 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2808 def kind @kind end |
#name ⇒ String
The base type or composite type name.
Corresponds to the JSON property name
2813 2814 2815 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2813 def name @name end |
#schema ⇒ Google::Apis::DeploymentmanagerV2beta::TypeInfoSchemaInfo
For base types with a collection, we return a schema and documentation link
For template types, we return only a schema
Corresponds to the JSON property schema
2819 2820 2821 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2819 def schema @schema end |
#self_link ⇒ String
Output only. Self link for the type provider.
Corresponds to the JSON property selfLink
2824 2825 2826 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2824 def self_link @self_link end |
#title ⇒ String
The title on the API descriptor URL provided.
Corresponds to the JSON property title
2829 2830 2831 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2829 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2836 2837 2838 2839 2840 2841 2842 2843 2844 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2836 def update!(**args) @description = args[:description] if args.key?(:description) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @schema = args[:schema] if args.key?(:schema) @self_link = args[:self_link] if args.key?(:self_link) @title = args[:title] if args.key?(:title) end |