Class: Google::Apis::DeploymentmanagerV2beta::TypeProvider
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2beta::TypeProvider
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2beta/classes.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb,
lib/google/apis/deploymentmanager_v2beta/representations.rb
Overview
A type provider that describes a service-backed Type.
Instance Attribute Summary collapse
-
#collection_overrides ⇒ Array<Google::Apis::DeploymentmanagerV2beta::CollectionOverride>
Allows resource handling overrides for specific collections Corresponds to the JSON property
collectionOverrides. -
#credential ⇒ Google::Apis::DeploymentmanagerV2beta::Credential
The credential used by Deployment Manager and TypeProvider.
-
#custom_certificate_authority_roots ⇒ Array<String>
List of up to 2 custom certificate authority roots to use for TLS authentication when making calls on behalf of this type provider.
-
#description ⇒ String
An optional textual description of the resource; provided by the client when the resource is created.
-
#descriptor_url ⇒ String
Descriptor Url for the this type provider.
-
#id ⇒ Fixnum
Output only.
-
#insert_time ⇒ String
Output only.
-
#labels ⇒ Array<Google::Apis::DeploymentmanagerV2beta::TypeProviderLabelEntry>
Map of One Platform labels; provided by the client when the resource is created or updated.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#operation ⇒ Google::Apis::DeploymentmanagerV2beta::Operation
Represents an Operation resource.
-
#options ⇒ Google::Apis::DeploymentmanagerV2beta::Options
Options allows customized resource handling by Deployment Manager.
-
#self_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TypeProvider
constructor
A new instance of TypeProvider.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TypeProvider
Returns a new instance of TypeProvider.
2990 2991 2992 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2990 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection_overrides ⇒ Array<Google::Apis::DeploymentmanagerV2beta::CollectionOverride>
Allows resource handling overrides for specific collections
Corresponds to the JSON property collectionOverrides
2907 2908 2909 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2907 def collection_overrides @collection_overrides end |
#credential ⇒ Google::Apis::DeploymentmanagerV2beta::Credential
The credential used by Deployment Manager and TypeProvider. Only one of the
options is permitted.
Corresponds to the JSON property credential
2913 2914 2915 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2913 def credential @credential end |
#custom_certificate_authority_roots ⇒ Array<String>
List of up to 2 custom certificate authority roots to use for TLS
authentication when making calls on behalf of this type provider. If set, TLS
authentication will exclusively use these roots instead of relying on publicly
trusted certificate authorities when validating TLS certificate authenticity.
The certificates must be in base64-encoded PEM format. The maximum size of
each certificate must not exceed 10KB.
Corresponds to the JSON property customCertificateAuthorityRoots
2923 2924 2925 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2923 def @custom_certificate_authority_roots end |
#description ⇒ String
An optional textual description of the resource; provided by the client when
the resource is created.
Corresponds to the JSON property description
2929 2930 2931 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2929 def description @description end |
#descriptor_url ⇒ String
Descriptor Url for the this type provider.
Corresponds to the JSON property descriptorUrl
2934 2935 2936 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2934 def descriptor_url @descriptor_url end |
#id ⇒ Fixnum
Output only. Unique identifier for the resource defined by the server.
Corresponds to the JSON property id
2939 2940 2941 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2939 def id @id end |
#insert_time ⇒ String
Output only. Creation timestamp in RFC3339 text format.
Corresponds to the JSON property insertTime
2944 2945 2946 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2944 def insert_time @insert_time end |
#labels ⇒ Array<Google::Apis::DeploymentmanagerV2beta::TypeProviderLabelEntry>
Map of One Platform labels; provided by the client when the resource is
created or updated. Specifically: Label keys must be between 1 and 63
characters long and must conform to the following regular expression: [a-z]([-
a-z0-9]*[a-z0-9])? Label values must be between 0 and 63 characters long and
must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)?
Corresponds to the JSON property labels
2953 2954 2955 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2953 def labels @labels end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression [a-z]([-a-
z0-9]*[a-z0-9])? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
2963 2964 2965 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2963 def name @name end |
#operation ⇒ Google::Apis::DeploymentmanagerV2beta::Operation
Represents an Operation resource. Google Compute Engine has three Operation
resources: * Global * Regional * Zonal You can use an operation resource to manage asynchronous API
requests. For more information, read Handling API responses. Operations can be
global, regional or zonal. - For global operations, use the globalOperations
resource. - For regional operations, use the regionOperations resource. -
For zonal operations, use the zoneOperations resource. For more information,
read Global, Regional, and Zonal Resources. Note that completed Operation
resources have a limited retention period.
Corresponds to the JSON property operation
2978 2979 2980 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2978 def operation @operation end |
#options ⇒ Google::Apis::DeploymentmanagerV2beta::Options
Options allows customized resource handling by Deployment Manager.
Corresponds to the JSON property options
2983 2984 2985 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2983 def @options end |
#self_link ⇒ String
Output only. Self link for the type provider.
Corresponds to the JSON property selfLink
2988 2989 2990 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2988 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 |
# File 'lib/google/apis/deploymentmanager_v2beta/classes.rb', line 2995 def update!(**args) @collection_overrides = args[:collection_overrides] if args.key?(:collection_overrides) @credential = args[:credential] if args.key?(:credential) @custom_certificate_authority_roots = args[:custom_certificate_authority_roots] if args.key?(:custom_certificate_authority_roots) @description = args[:description] if args.key?(:description) @descriptor_url = args[:descriptor_url] if args.key?(:descriptor_url) @id = args[:id] if args.key?(:id) @insert_time = args[:insert_time] if args.key?(:insert_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @operation = args[:operation] if args.key?(:operation) @options = args[:options] if args.key?(:options) @self_link = args[:self_link] if args.key?(:self_link) end |